﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Steema.TeeChart;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;
using Steema.TeeChart.Tools;

namespace WindowsFormsApplication2
{
    public partial class Form1 : Form
    {
        TChart tChart1;
        public Form1()
        {
            InitializeComponent();
            tChart1 = new TChart();
            tChart1.Dock = DockStyle.Fill;
            this.panel2.Controls.Add(tChart1);           
        }

        private void InitializeChart()
        {
            string x = "XValues";
            string y = "YValues";
            string z = "ZValues";

            for (int i = 0; i < 60; i++)
            {
                AddSuface(CreateDataTable(x, y, z), x, y, z);
            }

            tChart1.Aspect.Orthogonal = false;
            tChart1.Aspect.Chart3DPercent = 75;
            tChart1.Aspect.Zoom = 80;
        }

        private DataTable CreateDataTable(string xColName, string yColName, string zColName)
        {
            DataTable result = new DataTable();
            result.Columns.Add(new DataColumn(xColName, typeof(double)));
            result.Columns.Add(new DataColumn(yColName, typeof(double)));
            result.Columns.Add(new DataColumn(zColName, typeof(double)));

            double x, y, z;
            Random rnd = new Random();
            //Modified by Alias: Incremented loop counter to 1000
            for (int i = 0; i < 1000; i++)
            {
                x = i;
                for (int j = 0; j < 1000; j++)
                {
                    z = j;
                    y = Math.Cos(i * 10) * Math.Sin(j * 10);
                    DataRow row = result.NewRow();
                    row[0] = x;
                    row[1] = y;
                    row[2] = z;
                    result.Rows.Add(row);
                }
            }

            return result;
        }

        void AddSuface(DataTable dataSourceTable, string xColName, string yColName, string zColName)
        {
            try
            {
                Surface surface = new Surface();
                surface.IrregularGrid = true;
                //Add data to the surface object
                for (int Index = 0; Index < dataSourceTable.Rows.Count; Index++)
                {
                    DataRow xrow = dataSourceTable.Rows[Index];
                    double xVal = Convert.ToDouble(xrow[xColName]);
                    for (int Index1 = 0; Index1 < dataSourceTable.Rows.Count; Index1++)
                    {
                        DataRow row = dataSourceTable.Rows[Index1];
                        double zVal = Convert.ToDouble(row[zColName]);
                        double yVal = Convert.ToDouble(row[yColName]);
                        surface.Add(xVal, yVal, zVal);
                    }
                }

                //surface.CheckDataSource();
                surface.UseColorRange = false;
                surface.UsePalette = true;
                surface.PaletteStyle = Steema.TeeChart.Styles.PaletteStyles.Rainbow;
                surface.PaletteSteps = 10;
            }
            catch(Exception ex)
            {               
                throw;
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            try
            {
                this.UseWaitCursor = true;
                this.Text = "Graph Generation is in progress wait till exception generated";
                InitializeChart();
                tChart1.ShowEditor();
                this.UseWaitCursor = false;
            }
            catch (OutOfMemoryException ex)
            {
                this.UseWaitCursor = false;
                string error = string.Format("Out of memory{0}{1}{2}{3}{4}", ex.Source, ex.TargetSite, ex.TargetSite, ex.Message,ex.StackTrace);
                //MessageBox.Show("Out of memory");
                MessageBox.Show(error);

            }
            catch (Exception ex)
            {
                MessageBox.Show("General Error");
            }
        }
    }
}
